@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: polyparse
 version: 1.11
-id: polyparse-1.11-32e1e4b83edd269be9945c81b189424b
-key: polyp_GRsQpXwvEUxJXetVpxpw1R
+id: polyparse-1.11-e9f1a767e0f506fecd31d2edb677e294
+key: polyp_Jfel2PmSmABKWehalNK8FT
 license: LGPL
 maintainer: author
 homepage: http://code.haskell.org/~malcolm/polyparse/
@@ -37,11 +37,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/polyparse-1.11
-hs-libraries: HSpolyparse-1.11-GRsQpXwvEUxJXetVpxpw1R
+hs-libraries: HSpolyparse-1.11-Jfel2PmSmABKWehalNK8FT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
 haddock-html: /usr/share/doc/haskell-polyparse/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
